@@ -7,6 +7,7 @@ import os
 import re
 from stat import S_IRGRP, S_IROTH, S_IRUSR, S_IWGRP, S_IWOTH, S_IWUSR
 
+# pylint: disable=redefined-builtin
 from ._exceptions import FileNotFoundError
 
 MAXLEN = 120
@@ -15,6 +16,7 @@ LOGGER = logging.getLogger(__name__)
 MODE666 = S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH
 
 
+# pylint: disable=useless-object-inheritance
 class File(object):
     """Easy manipulation of files in the SAME directory."""
 
@@ -45,8 +47,8 @@ class File(object):
     def mkwinsafe(name, space=' '):
         """Delete most common characters not allowed in Windows filenames."""
         space = space if space not in ILEGAL else ' '
-        name = ''.join(c for c in name if c not in ILEGAL)\
-               .replace(' ', space).strip()
+        name = ''.join(c for c in name
+                       if c not in ILEGAL).replace(' ', space).strip()
         name = re.sub(r'\s\s+', ' ', name) if space == ' ' else name
         return name[:MAXLEN]
 
@@ -54,14 +56,14 @@ class File(object):
     def validate(basename):
         """Check for a proper basename."""
         if basename != os.path.basename(basename):
-            LOGGER.critical("This (%s) is not a basename!", basename)
+            LOGGER.critical('This (%s) is not a basename!', basename)
             return False
         name, ext = os.path.splitext(basename)
         if not name:
-            LOGGER.critical("Not a valid name (lenght 0)!")
+            LOGGER.critical('Not a valid name (lenght 0)!')
             return False
         if not ext:
-            LOGGER.critical("Not a valid extension (lenght 0)!")
+            LOGGER.critical('Not a valid extension (lenght 0)!')
             return False
         return True
 
@@ -78,13 +80,13 @@ class File(object):
             try:
                 os.rename(self.basename, new_basename)
             except OSError as err:
-                LOGGER.critical("%s", err)
+                LOGGER.critical('%s', err)
                 return False
             self.basename = new_basename
             self.name = name
             self.ext = ext
         else:
-            LOGGER.info("The file (%s) already exist in the directory!",
+            LOGGER.info('The file (%s) already exist in the directory!',
                         new_basename)
         return True
 
